@@ -28,6 +28,15 @@ def course(request, course):
         'course': course,
     })
 
+@login_required
+@needs_course
+def topic(request, course, topic_nr):
+    topic = get_object_or_404(Topic, course=course, number=topic_nr)
+    return render(request, 'autodidact/topic.html', {
+        'topic': topic,
+        'course': course,
+    })
+
 @login_required
 @needs_course
 @needs_session
@@ -115,7 +124,7 @@ def progresses(request, course, session):
         s.answers = answers
 
     if filetype == 'csv':
-        response = render(request, 'autodidact/students.csv', {'students': students})
+        response = render(request, 'autodidact/students.csv', {'assignments': assignments, 'students': students})
         response['Content-Disposition'] = 'attachment; filename="{}_session{}.csv"'.format(course.slug, session.nr)
         return response
     else:
